@@ -1783,13 +1783,14 @@ main (argc, argv)
   int status = EXIT_SUCCESS;
   int stdin_file_list = 0;
   int optchar;
+  char *localedir;
 
   program_name = argv[0];
   sharpid = (int) getpid ();
   setlocale (LC_ALL, "");
 
   /* Set the text message domain.  */
-  bindtextdomain (PACKAGE, LOCALEDIR);
+  localedir = bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 
   while (optchar = getopt_long (argc, argv,
@@ -1965,13 +1966,7 @@ main (argc, argv)
     || (defined HAVE_GETTEXT && !defined __USE_GNU_GETTEXT)
       exit (EXIT_FAILURE);
 #else
-#ifdef __CYGWIN__
-      extern const char __declspec(dllimport) _nl_default_dirname__[];
-      puts (_nl_default_dirname__);
-#else
-      extern const char _nl_default_dirname[]; /* Defined in dcgettext.c  */
-      puts (_nl_default_dirname);
-#endif
+      puts (localedir);
       exit (EXIT_SUCCESS);
 #endif
     }
